# Maintainers

This file contains information about people permitted to make major decisions and direction on the project.

## Contributing Under the DCO

By adding your name and email address to this section, you certify that all of your subsequent contributions to
incorporeal-cms are made under the terms of the Developer's Certificate of Origin 1.1, available at `DCO.txt`.

* Brian S. Stephan (<bss@incorporeal.org>)
